Monty Python's Flying Circus: Just the Words - Episode 15

# Episode Fifteen

Man-powered flight
The Spanish Inquisition
Jokes and novelties salesman
Tax on thingy
Vox pops on tax
Photos of Uncle Ted (Spanish Inquisition)
The semaphore version of 'Wuthering Heights'
'Julius Caesar' on an Aldis lamp
Court scene (charades)

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| A field. A man with large mechanical wings, pulleys and gears contraption, running along trying to fly. Cut to him going faster. Cut to him going even faster. Cut to him even faster and suddenly he appears to take off, jumping off a dune or a hillock. Cut to him flying in slow motion so that it looks like he is gliding. He hits what seems to be a cliff. Camera twists round so that it is the right way up, showing that the flyer has fallen down a cliff onto a beach. It pans across from the wreck of the flyer. As it pans across the sand, various other would-be fliers can be seen, heads in the sand, legs kicking up in the air, amidst the broken debris of their planes. Camera continues to pan until it comes across an announcer in DJ sitting at his desk:
Announcer | And now for something completely different.
It's Man | It's...
| Animated titles. Music: Black Dyke Mills Band playing a slow dirge. Stock shot of mill town at the turn of the century - at night. SUBTITLE: 'JARROW - NEW YEAR'S EVE 1911' SUBTITLE: 'JARROW 1912' Mix through to mill-owner's opulent sitting room at the turn of the century. Lady Mountback sits with her crochet. There is a knock on the door.
Lady Mountback | Come in.
| Enter Reg, cap in hand.
Reg | Trouble at mill.
Lady Mountback | Oh no. What sort of trouble?
Reg | One on't cross beams gone owt askew on treddle.
Lady Mountback | Pardon?
Reg | One on't cross beams gone owt askew on treddle.
Lady Mountback | I don't understand what you're saying.
Reg | (slightly irritatedly and with exaggeratedly clear accent) One of the cross beams has gone out askew on the treddle.
Lady Mountback | Well what on earth does that mean?
Reg | I don't know. Mr Wentworth just told me to come in here and say that there was trouble at the mill, that's all - I didn't expect a kind of Spanish Inquisition.
| Jarring chord. The door flies open and Cardinal Ximinez of Spain enters, flanked by two junior cardinals. Cardinal Biggles has goggles pushed over his forehead. Cardinal Fang is just Cardinal Fang.
Ximinez | Nobody expects the Spanish Inquisition! Our chief weapon is surprise...surprise and fear...fear and surprise.... our two weapons are fear and surprise...and ruthless efficiency.... Our three weapons are fear, surprise, and ruthless efficiency...and an almost fanatical devotion to the Pope.... Our four...no... amongst our weapons.... amongst our weaponry...are such elements as fear, surprise.... I'll come in again. (exit and exeunt)
Reg | I didn't expect a kind of Spanish Inquisition.
| Jarring chord. They burst in.
Ximinez | Nobody expects the Spanish Inquisition! Amongst our weaponry are such diverse elements as fear, surprise, ruthless efficiency, and an almost fanatical devotion to the Pope, and nice red uniforms - oh damn! (to Biggles) I can't say it, you'll have to say it.
Biggles | What?
Ximinez | You'll have to say the bit about 'Our chief weapons are ...'
Biggles | I couldn't do that...
| Ximinez bundles the cardinals outside.
Reg | I didn't expect a kind of Spanish Inquisition.
| They all enter.
Biggles | Er.... Nobody...um....
Ximinez | Expects.
Biggles | Expects... Nobody expects the...um...the Spanish...um...
Ximinez | Inquisition.
Biggles | I know...I know! Nobody expects the Spanish Inquisition. In fact, those who do expect...
Ximinez | Our chief weapons are...
Biggles | Our chief weapons are...um...er...
Ximinez | Surprise.
Biggles | Surprise and...
Ximinez | Stop. Stop there! Stop there. Whew! Our chief weapon is surprise, blah, blah, blah, blah. Cardinal, read the charges.
Fang | You are hereby charged that you did on diverse dates commit heresy against the Holy Church. My old man said follow the...
Biggles | That's enough. (to Lady Mountback) Now, how do you plead?
Lady Mountback | We're innocent.
Ximinez | Ha! Ha! Ha! Ha! Ha!
| SUPERIMPOSED CAPTION: 'DIABOLICAL LAUGHTER'
Biggles | We'll soon change your mind about that!
| SUPERIMPOSED CAPTION: 'DIABOLICAL ACTING'
Ximinez | Fear, surprise, and a most ruthless... (controls himself with a supreme effort) ooooh! Now, Cardinal, the rack!
| Biggles produces a plastic-coated dish-drying rack. Ximinez looks at it and clenches his teeth in an effort not to lose control. He hums heavily to cover his anger.
Ximinez | You....Right! Tie her down. (Fang and Biggles make a pathetic attempt to tie her on to the drying rack) Right! How do you plead?
Lady Mountback | Innocent.
Ximinez | Ha! Right! Cardinal, give the rack (oh dear) give the rack a turn.
| Cardinal Biggles stands their awkwardly and shrugs.
Biggles | I....
Ximinez | (gritting his teeth) I know. I know you can't. I didn't want to say anything. I just wanted to try and ignore your crass mistake.
Biggles | I...
Ximinez | It makes it all seem so stupid.
Biggles | Shall I, um...?
Ximinez | Oh, go on, just pretend for God's sake.
| Biggles turns an imaginary handle on the side of the rack. The doorbell rings. Reg detaches himself from the scene and answers it. Outside there is a dapper BBC man with a suit and a beard, slightly arty.
BBC Man | Ah, hello, you don't know me, but I'm from the BBC. We were wondering if you'd come and answer the door in a sketch over there, in that sort of direction... You wouldn't have to do anything - just open the door and that's it.
Reg | Oh, well all right, yes.
BBC Man | Jolly good. Come this way.
| Cut to film of them coming out of the front door of the house and walking to BBC van. Conversation is heard throughout (slightly faintly)..
BBC Man | Yes, we're on film at the moment you see.
Reg | It's a link, is it?
BBC Man | Yes that's right, that sort of thing, yes, a link. It's all a bit zany - you know a bit madcap funster... frankly I don't fully understand it myself, the kids seem to like it. I much prefer Des O'Connor ... Rolf Harris ... Tom Jones, you know...
| They get into the van. It drives off. They pass an AA sign saying 'To the Sketch'. Panning shot of them, in which we see them convening and hear...
Reg | You do a lot of this sort of thing, do you?
BBC Man | Quite a lot yes, quite a lot. I'm mainly in comedy. I'd like to be in Programming Planning actually, but unfortunately I've got a degree.
| They arrive outside a suburban house, where the novelty salesman, Mr Johnson, is already waiting outside the front door. BBC man points and gives Reg direction. Reg goes to the door saying: 'Excuse me' and goes in, closing the front door. The novelty man rings bell. Reg opens the door.
Johnson | Joke, sir? Guaranteed amusing. As used by the crowned heads of Europe. Has brought tears to the eyes of Royalty. 'Denmark has never laughed so much' - 'The Stage'. Nice little novelty number - 'a naughty Humphrey' - breaks the ice at parties. Put it on the table. Press the button. It vomits. Absolutely guaranteed. With refills. 'Black soap' - leave it in the bathroom, they wash their hands, real fungus grows on the fingers. Can't get it off for hours. Guaranteed to break the ice at parties. Frighten the elderly - real snakes. Comedy hernia kit. Plastic flesh wounds - just keep your friends in stitches. Guaranteed to break the ice at parties. Hours of fun with 'honeymoon delight' - empty it into their beds - real skunk juice. They won't forget their wedding night. Sticks to the skin, absolutely waterproof, guaranteed to break the ice at parties. Amuse your friends - CS gas canisters - smells, tastes and acts just like the real thing - can blind, maim or kill. Or for drinks, why not buy a 'wicked willy' with a life-size winkle - serves warm beer. Makes real cocktails. Hours of amusement. Or get the new Pooh-Pooh machine. Embarrass your guests - completely authentic sound. Or why not try a new 'naughty nightie' - put it on and it melts - just watch their faces. Guaranteed to break the ice at naughty parties. Go on, go on.
Reg | What?
Johnson | Do the punchline.
Reg | What punchline?
Johnson | The punchline for this bit.
Reg | I don't know it. They didn't say anything about a punchline.
Johnson | Oh! Oh well in that case I'll be saying goodbye then, sir... Goodbye then, sir.
| He turns and walks away. Reg looks around desperately. And then runs out of the door. He runs to BBC van as Johnson walks out of picture. Cut to cabin of BBC van with the BBC man sitting there.
Reg | What's the punchline?
BBC Man | Punchline? I don't think there's a punchline scheduled, is there? Where are we? A week 39.4 no, it's Friday, isn't it - 39.7. Oh ... here we are. Oh! (laughs) Ha, ha, ha, very good. Ha, ha, ha, very good. What a good punchline. Pity we missed that. Still, never mind, we can always do it again. Make a series out of it. Now if you'll just sign there, I'll put this through to our contracts department and you should be hearing from them in a year or two.
Reg | Can you give me a lift back?
BBC Man | Ah - can do. But won't. We were wondering if we could possibly borrow your head for a piece of animation.
Reg | What?
BBC Man | Oh jolly good. Thanks very much. You will get expenses.
| BBC staff set on Reg and saw his head off. ANIMATION: Reg's head starts off by being thrown into picture. Animation leads to an oak panelled, Civil Service committee room. A politician is addressing three officals.
Politician | Gentlemen, our MP saw the PM this AM and the PM wants more LSD from the PIB by tomorrow AM or PM at the latest. I told the PM's PPS that AM was NBG so tomorrow PM it is for the PM nem. con. Give us a fag or I'll go spare. Now, the fiscal deficit with regard to the monetary balance, the current financial year excluding invisible exports, but adjusted of course for seasonal variations and the incremental statistics of the fiscal and revenue arrangements for the forthcoming annual budgetary period terminating in April.
First Official | I think he's talking about taxation.
Politician | Bravo, Madge. Well done. Taxation is indeed the very nub of my gist. Gentlemen, we have to find something new to tax.
Second Official | I understood that.
Third Official | If I might put my head on the chopping block so you can kick it around a bit, sir...
Politician | Yes?
Third Official | Well most things we do for pleasure nowadays are taxed, except one.
Politician | What do you mean?
Third Official | Well, er, smoking's been taxed, drinking's been taxed but not ... thingy.
Politician | Good Lord, you're not suggesting we should tax... thingy?
First Official | Poo poo's?
Third Official | No.
First Official | Thank God for that. Excuse me for a moment. (leaves)
Third Official | No, no, no - thingy.
Second Official | Number ones?
Third Official | No, thingy.
Politician | Thingy!
Second Official | Ah, thingy. Well it'll certainly make chartered accountancy a much more interesting job.
| Cut to vox pops.
Gumby | (standing in water) I would put a tax on all people who stand in water ... (looks round him)... Oh!
Man In Bowler Hat | To boost the British economy I'd tax all foreigners living abroad.
Man In Suit | I would tax the nude in my bed. No - not tax. What is the word? Oh - 'welcome'.
It's Man | I would tax Racquel Welch. I've a feeling she'd tax me.
First Business Man | Bring back hanging and go into rope.
Second Business Man | I would cut off the more disreputable parts of the body and use the space for playing fields.
Man In Cap | I would tax holiday snaps.
| Freeze frame. Cut to snapshot of same stil which is being held by a dear old lady. Pull out to reveal she is sitting with a large photo album on her knees, lovingly extracting photos from the piles on top of the album and passing them to her friend sitting on the same settee. Her friend is a young lady, who tears up the photos as they are handed to her. The dear old lady is in a world of her own and does not notice.
Dear Old Lady (Marjorie Wilde) | This is Uncle Ted in front of the house. (she hand over the photo and the young lady tears it up) This is Uncle Ted at the back of the house. (she hand over the photo and the young lady tears it up) And this is Uncle Ted at the side of the house. (she hand over the photo and the young lady tears it up) This is Uncle Ted back in front of the house, but you can see the side of the house. (she hand over the photo and the young lady tears it up) And this is Uncle Ted even nearer the side of the house, but you can still see the front. (she hand over the photo and the young lady tears it up) This is the back of the house, with Uncle Ted coming round the side to the front. (she hand over the photo and the young lady tears it up) And the is the Spanish Inquisition hiding behind the coal shed.
| Friend takes it with the first sign of real interest.
Young Lady | Oh! I didn't expect a Spanish Inquisition.
| Jarring chord. The door flies open and Ximinez, Biggles and Fang enter.
Ximinez | Nobody expects the Spanish Inquisition!
| Cut to film: moving over Breugel drawing of tortures; epic film music.
Voice Over | (and CAPTION:) 'IN THE EARLY YEARS OF THE SIXTEENTH CENTURY, TO COMBAT THE RISING TIDE OF RELIGIOUS UNORTHODOXY, THE POPE GAVE CARDINAL XIMINEZ OF SPAIN LEAVE TO MOVE WITHOUT LET OR HINDRANCE THROUGHOUT THE LAND, IN A REIGN OF VIOLENCE, TERROR AND TORTURE THAT MAKES A SMASHING FILM. THIS WAS THE SPANISH INQUISITION...'
| Torchlit dungeon. We hear clanging footsteps. Shadows on the Grille. The footsteps stop and keys jangle. The great door creaks open and Ximinez walks in and looks round approvingly. Fang and Biggles enter behind pushing in the dear old lady. They chain her to the wall.
Ximinez | Now, old woman! You are accused of heresy on three counts. Heresy by thought, heresy by word, heresy by deed, and heresy by action. Four counts. Do you confess?
Dear Old Lady | I don't understand what I'm accused of.
Ximinez | Ha! Then we shall make you understand...Biggles! Fetch...the cushions!
| Jarring chord. Biggles holds out two ordinary modern household cushions.
Biggles | Here they are, lord.
Ximinez | Now, old lady, you have one last chance. Confess the heinous sin of heresy, reject the works of the ungodly - two last chances. And you shall be free...three last chances. You have three last chances, the nature of which I have divulged in my previous utterance.
Dear Old Lady | I don't know what you're talking about.
Ximinez | Right! If that's the way you want it - Cardinal! Poke her with the soft cushions! (Biggles carries out this rather pathetic torture) Confess! Confess! Confess!
Biggles | It doesn't seem to be hurting her, my lord.
Ximinez | Have you got all the stuffing up one end?
Biggles | Yes, lord.
Ximinez | (angrily hurling away the cushions) Hm! She is made of harder stuff! Cardinal Fang - fetch...the comfy chair!
| Another loud jarring chord. Zoom in on Fang's horrified face.
Fang | The comfy chair?
| Fang pushes in a comfy chair - a really plush one.
Ximinez | So you think you are strong because you can survive the soft cushions. Well, we shall see. Biggles! Put her in the Comfy Chair! (Biggles roughly push her into the comfy chair) Now. You will stay in the Comfy Chair until lunch time, with only a cup of coffee at eleven... (to Biggles) Is that really all it is?
Biggles | Why, yes lord.
Ximinez | I see. I suppose we make it worse by shouting a lot, do we? Confess, woman. Confess! Confess! Confess! Confess!
Biggles | I confess!
Ximinez | Not you!
Animation Voice | I confess.
Ximinez | Who was that?
| ANIMATION: 'I confess'
Voice Over | And now for the very first time on the silver screen comes the film from two books which once shocked a generation. From Emily Brontë's 'Wuthering Heights' and from the 'International Guide to Semaphore Code'. Twentieth Century Vole presents 'The Semaphore Version of Wuthering Heights'.
| CAPTION: 'THE SEMAPHORE VERSION OF WUTHERING HEIGHTS' Film: appropriate film music throughout. Heathcliffe (Terry J) in close-up profile, his hair is blowing in the wind, he looks intense. Cut to close-up Catherine (Carol) also in profile, with hair streaming in wind. As if they are looking into each other's eyes. Pull out to reveal, on very long zoom, that they are each on the top of separate small hills, in rolling countryside. Heathcliffe produces two semaphore flags from behind him, and waves them.
| SUBTITLE: 'OH! CATHERINE'
| Pan across to Catherine who also produces two flags and waves.
| SUBTITLE: 'OH! HEATHCLIFFE'
| Heathcliffe waves flags again.
| SUBTITLE: 'OH! OH! CATHERINE'
| With each cut they are further and further away from each other. Catherine waves flags again.
| SUBTITLE: 'OH! OH! HEATHCLIFFE'
| Cut to her husband at front door of early Victorian manor house, looking stem. He waves two flags.
| SUBTITLE: 'CATHERINE!'
| Cut back to Catherine on hilltop.
| SUBTITLE: 'HARK! I HEAR MY HUSBAND'
| Cut to husband with two enormous flags.
| SUBTITLE: 'CATHERINE!'
| Cut to intertor of the early Victorian manor house. Close-up of a cradle. Suddenly two little semaphore flags pop up from inside the cradle and wave.
| SUBTITLE: 'WAAAAAGH! WAAAAAAGH!'
| Pull back to reveal a nurse who walks over to cradle and waves flag briefly.
| SUBTITLE: 'SSSH!'
| The nurse points across the room. Cut to shot of old man asleep in chair with head slumped forward on his chest. He has two flags which he waves.
| SUBTITLE: 'ZZZ . . . ZZZ . . .'
| Cut to front door again. Exterior. Husband is waiting. Catherine comes up the path towards him. As she approaches he flags.
| SUBTITLE: 'YOU'VE BEEN SEEING HEATHCLIFFE'
| Catherine waves frantically.
| SUBTITLE: 'YES! YES! I'VE BEEN SEEING HEATHCLIFFE, AND WHY NOT? HE'S THE ONLY MAN I EVER LOVED. HE'S FINE. HE'S STRONG. HE'S ALL THE THINGS YOU'LL NEVER BE, AND WHAT'S MORE . . .'
| CAPTION: 'MONDAY FOR 7 DAYS' Stock film of a Roman chariot race.
Voice Over | From the pulsating pages of history, from the dark and furious days of Imperial Rome we bring you a story that shattered the world! A tale so gripping that they said it could not he filmed. A unique event in cinema history! Julius Caesar on an Aldis lamp!
| SUPERIMPOSED CAPTION: 'JULIUS CAESAR ON AN ALDIS LAMP' Close-up of Caesar walking in Roman street. Soothsayer pushes his way up to him wild eyed and produces Aldis lamp and starts flashing: SUBTITLE: 'BEWARE THE IDES OF MARCH' Some steps at the foot of a statue. Caesar is stabbed. As he falls he brings out a really big Aldis lamp and flashes to the assassins around him. SUBTITLE: 'ET TU BRUTE' A Western street. Two cowboys facing each other with morse buzzers.
Voice Over | From the makers of 'Gunfight at the OK Corral in Morse Code'.
| SUPERIMPOSED CAPTION: 'GUNFIGHT AT THE OK CORRAL IN MORSE CODE' They buzz a bit. SUBTITLE: 'AAAAHHHI' Cut to a Red Indian making smoke signals.
Voice Over | And the smoke-signal version of 'Gentlemen Prefer Blondes'.
| SUPERIMPOSED CAPTION: 'AND THE SMOKE-SIGNAL VERSION OF GENTLEMEN PREFER BLONDES' Cut to a court room. SUPERIMPOSED CAPTION: 'CENTRAL CRIMINAL COURT'
Judge | Ladies and gentlemen of the jury, have you reached a verdict?
Foreman | We have m'lud.
Judge | And how do you find the defendant? (the foreman puts his hand out with two fingers extended) Two words. (the foreman nods and holds up one finger) First word. (the foreman mimes taking a piece of string and tying it in knot) Rope? String?
| The foreman shakes his head and points to the knot.
Counsel | Point?
Clerk | Belt?
Judge | Tie?
| The foreman nods and points to the knot.
Counsel | Cravat? Silk square?
Clerk | Knot?
| The foreman nods enthusiasticaly.
All | Knot!
| The foreman gives a thumbs up and points to his second finger.
Judge | Second word. (foreman indicates two syllables) Two syllables. (the foreman points to his first finger) First syllable. (the foreman starts to mime a fish while pointing at his throat) Bird?
Clerk | Swimmer?
Judge | Breast stroke.
Counsel | Brian Phelps.
Judge | No, no, no, he was a diver.
Clerk | Esther Williams then.
Judge | No, no, don't be silly. How can you find someone 'Not Esther Williams'.
Counsel | Fish. (the foreman nods and points at throat) Fish wheeze. Fish wheeze?
Judge | Fish breathe.
Counsel | Fish breathe, throat.
Judge | Fish breathe, throat? GILL! (the foreman gives a thumbs up and the court applauds excitedly) Not gill. (the foreman mimes the second syllable) Second syllable. Not gill.
| Foreman mimes drinking a cup of tea.
Counsel | Drink.
Clerk | Sip? Imbibe?
| The foreman points to the mimed cup itself.
Judge | Not gill ... cup? Not gillcup! (the foreman looks disappointed) You have been found not gillcup of the charges brought against you and may leave this court a free man. Right. My turn. (the defendant leaves.)
| The judge holds up four fingers.
Counsel | Four words.
| The judge mimes shouting for the first word.
Foreman | First word shout?
Counsel | Bellow?
Clerk | Call?
All | Call!
| The judge gives a thumbs up and indicates that the second word is very small.
Counsel | Second word is very small.
Foreman | A?
Counsel | An?
Clerk | Up?
Foreman | The?
| The judge gives a thumbs up.
All | The!
Clerk | Call the, third word:
| The judge points to his neck.
Counsel | Gill?
Member of Jury | Fish?
Clerk | Adam's apple. (the judge shakes his head) Neck. (the judge mime 'sounds like') Sounds like neck?
Second Counsel | Next.
Foreman | Call the ... next!
| The judge gives a thumbs up and indicates that the fourth word is three Syllables. First syllable: he mimes deafness.
Clerk | Fourth word, three syllables. First syllable ... ear?
Counsel | Hear. Can't hear.
Clerk | Deaf!! Call the next def-.
| The judge leaps onto the desk and points at his own bottom.
Counsel | Bottom.
Clerk | Seat? Trouser? Cheek?
Foreman | End! Call the next defend-.
| The judge leaps down, disappears under the desk and appears with an enormous model of an ant about four feet long.
Whole Court | Ant!
Clerk | Call the next defendant! (the court applauds the judge who bows and sits; the whole mood changes) Call the next defendant. The Honourable Mr Justice Kilbraken. (a very elderly judge in full robes comes into the dock) If I may charge you m'lud, you are charged m'lud that on the fourteenth day of June 1970, at the Central Criminal Court, you did commit acts likely to cause a breach of the peace. How plead you m'lud, guilty or not guilty?
Judge Kilbraken | Not guilty. Case not proven. Court adjourned.
| He hits the dock. Everyone gets up and starts walking out talking to each other.
Judge | No, no, no, no, no, no, no. (they all stop, go back and sit down again) No, you're in the dock, m'lud.
Judge Kilbraken | I'm a judge, m'lud.
Judge | So am I, m'lud, so watch it.
Judge Kilbraken | Hah! Call this a court.
All | Call this a court. Call this a court..Call this a court.
Judge | Shut up. Right now get on with the spiel.
Counsel | M'lud, and my other lud, the prosecution will endeavour to show m'lud, that m'lud - ah, not you m'lud, that m'lud, m'lud, while passing sentence at the Central Criminal Court blotted his copy book. Call exhibit Q.
Judge | Q?
Counsel | Sorry did I say Q? I meant A. Sorry, call exhibit A.
Clerk | Call exhibit A.
| Two court ushers carry in a thing with a sheet over it. They pull off the sheet to reveal a very sexy girl in a provocative pose.
Counsel | Exhibit A m'lud, Miss Rita Thang, an artist's model, Swedish accordion teacher and cane-chair sales lady, was found guilty under the Rude Behaviour Act in the accused's court. The accused, m'lud, sentenced her to be taken from this place and brought round to his place.
Second Counsel | Objection, m'lud.
Judge Kilbraken | Objection sustained.
Judge | You shut up! Objection overruled.
Counsel | The accused then commented on Miss Thang's bodily structure, made several not-at-all legal remarks on the subject of fun and then placed his robes over his head and began to emit low moans.
Judge | Have you anything to say in your defense?
Judge Kilbraken | I haven't had any for weeks.
Judge | Oh no? What about that little number you've got tucked away in Belsize Park?
Judge Kilbraken | Oh, I never!
Judge | Oh no. Ho! Ho! Ho!
Judge Kilbraken | All right then what about 8a Woodford Square?
Judge | You say anything about that and I'll do you for treason.
Counsel | M'lud if we could continue ...
Judge Kilbraken | He's got a Chinese bit there.
Judge | No, that's contempt of court.
Judge Kilbraken | It was only a joke.
Judge | Contempt of court. However, I'm not going to punish you, because we're so short of judges at the moment, what with all of them emigrating to South Africa. I'm going tomorrow; I've got my ticket. Get out there and get some decent sentencing done. Ooh, England makes you sick. Best I can manage here is life imprisonment. It's hardly worth coming in in the morning. Now, South Africa? You've got your cat of nine tails, you've got four death sentences a week, you've got cheap drinks, slave labour and a booming stock market. I'm off, I tell you. Yes, I'm up to here with probation and bleeding psychiatric reports. That's it, I'm off. That's it. Right. But I'm going to have one final fling before I leave, so I sentence you to be burnt at the stake.
Judge Kilbraken | Blimey! I didn't expect the Spanish Inquisition.
| Court reacts expectantly. Cut to suburban house. The three members of the Spanish Inquisition suddenly belt out of the door and down the path. Dick Barton music. Cut to them leaping onto a bus.
Ximinez | Two, er, three to the Old Bailey please.
| Credits start superimposed.
Biggles | Look they've started the credits.
Ximinez | Hurry. Hurry. Hurry.
Biggles | Come on hurry. Hurry!
| We see shots of them coming through London.
Ximinez | There's the lighting credit, only five left. (more shots of the bus going through London; the credits reach the producer) Hell, it's the producer - quick!
| They leap off the bus into the Old Bailey. Cut to court room. They burst in.
Ximinez | Nobody expects the Spa... ('The End' appears) Oh bugger!